@@ -55,9 +55,9 @@ if [ -x "/etc/init.d/benno-archive" ]; then
         sleep $i
     done
     echo ""
-    IPATTERN=$(/bin/echo "$SYSTEMINFO"|grep ImportPattern|cut -d: -f2)
+    IPATTERN=$(/bin/echo "$SYSTEMINFO"|grep ImportPattern|perl -p -e 's/ImportPattern:\s+//')
     if [ "${IPATTERN}x" != x ];then
-        INBOXDIR=$(dirname $IPATTERN)
+        INBOXDIR=$(dirname "$IPATTERN")
     else
         INBOXDIR=/srv/benno/inbox
     fi
